==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/roslyn/src/Features/RulesMissingDocumentation.md <==
# Rules without documentation

Rule ID | Missing Help Link | Title |
--------|-------------------|-------|
IDE0005_gen |  | Imports statement is unnecessary. |
IDE0043 |  | Invalid format string |
IDE0290 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0290> | Use primary constructor |
IDE0300 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0300> | Simplify collection initialization |
IDE0301 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0301> | Simplify collection initialization |
IDE0302 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0302> | Simplify collection initialization |
IDE0303 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0303> | Simplify collection initialization |
IDE0304 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0304> | Simplify collection initialization |
IDE0305 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0305> | Simplify collection initialization |
IDE0320 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0320> | Make anonymous function static |
IDE0330 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0330> | Use 'System.Threading.Lock' |
IDE1007 |  |  |
IDE2000 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2000> | Avoid multiple blank lines |
IDE2001 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2001> | Embedded statements must be on their own line |
IDE2002 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2002> | Consecutive braces must not have blank line between them |
IDE2003 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2003> | Blank line required between block and subsequent statement |
IDE2004 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2004> | Blank line not allowed after constructor initializer colon |
IDE2005 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2005> | Blank line not allowed after conditional expression token |
IDE2006 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2006> | Blank line not allowed after arrow expression clause token |
JSON001 |  | Invalid JSON pattern |
JSON002 |  | Probable JSON string detected |
RE0001 |  | Invalid regex pattern |
RemoveUnnecessaryImportsFixable |  |  |

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/roslyn/src/Features/RulesMissingDocumentation.md <==
# Rules without documentation

Rule ID | Missing Help Link | Title |
--------|-------------------|-------|
IDE0005_gen |  | Imports statement is unnecessary. |
IDE0043 |  | Invalid format string |
IDE0121 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0121> | Simplify LINQ expression |
IDE0290 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0290> | Use primary constructor |
IDE0300 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0300> | Simplify collection initialization |
IDE0301 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0301> | Simplify collection initialization |
IDE0302 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0302> | Simplify collection initialization |
IDE0303 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0303> | Simplify collection initialization |
IDE0304 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0304> | Simplify collection initialization |
IDE0305 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0305> | Simplify collection initialization |
IDE0306 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0306> | Simplify collection initialization |
IDE0320 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0320> | Make anonymous function static |
IDE0330 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0330> | Use 'System.Threading.Lock' |
IDE0340 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0340> | Use unbound generic type |
IDE0350 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0350> | Use implicitly typed lambda |
IDE0360 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide0360> | Simplify property accessor |
IDE1007 |  |  |
IDE2000 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2000> | Avoid multiple blank lines |
IDE2001 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2001> | Embedded statements must be on their own line |
IDE2002 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2002> | Consecutive braces must not have blank line between them |
IDE2003 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2003> | Blank line required between block and subsequent statement |
IDE2004 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2004> | Blank line not allowed after constructor initializer colon |
IDE2005 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2005> | Blank line not allowed after conditional expression token |
IDE2006 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide2006> | Blank line not allowed after arrow expression clause token |
JSON001 |  | Invalid JSON pattern |
JSON002 |  | Probable JSON string detected |
RE0001 |  | Invalid regex pattern |
RemoveUnnecessaryImportsFixable |  |  |
IDE3000 | <https://learn.microsoft.com/dotnet/fundamentals/code-analysis/style-rules/ide3000> | Implement with Copilot |
